summaryrefslogtreecommitdiffstats
path: root/flashrom.c
diff options
context:
space:
mode:
authorEdward O'Callaghan <quasisec@google.com>2022-10-26 13:46:14 +1100
committerEdward O'Callaghan <quasisec@chromium.org>2022-12-12 23:00:58 +0000
commit76f28a3fc29b96c1c8cc76cba1279f92d2edc86e (patch)
tree5f25bc8d28de469867e00b84c9d2026036eb9d9d /flashrom.c
parentd1212796abc68ff480ff862d1a09ec3a1942fe97 (diff)
downloadflashrom-76f28a3fc29b96c1c8cc76cba1279f92d2edc86e.tar.gz
flashrom-76f28a3fc29b96c1c8cc76cba1279f92d2edc86e.tar.bz2
flashrom-76f28a3fc29b96c1c8cc76cba1279f92d2edc86e.zip
tree/: Rename 'internal_delay()' to 'default_delay()'
The non-custom driver programmer delay implementation 'internal_delay()' is unrelated specifically to the 'internal' programmer. The delay implementation is simply a platform-agnostic host delay implementation. Therefore, rename to simply default_delay(). Change-Id: I5e04adf16812ceb1480992c92bca25ed80f8897a Signed-off-by: Edward O'Callaghan <quasisec@google.com> Reviewed-on: https://review.coreboot.org/c/flashrom/+/68855 Reviewed-by: Alexander Goncharov <chat@joursoir.net> Reviewed-by: Felix Singer <felixsinger@posteo.net> Tested-by: build bot (Jenkins) <no-reply@coreboot.org>
Diffstat (limited to 'flashrom.c')
-rw-r--r--flashrom.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/flashrom.c b/flashrom.c
index 18c486438..28201a703 100644
--- a/flashrom.c
+++ b/flashrom.c
@@ -260,18 +260,18 @@ void programmer_delay(const struct flashctx *flash, unsigned int usecs)
return;
/**
* Drivers should either use internal_delay() directly or their
* own custom delay. Only core flashrom logic calls programmer_delay()
* which should always have a valid flash context. A NULL context
* more than likely indicates a layering violation or BUG however
* for now dispatch a internal_delay() as a safe default for the NULL
* base case.
*/
if (!flash) {
msg_perr("%s called with NULL flash context. "
"Please report a bug at flashrom@flashrom.org\n",
__func__);
- return internal_delay(usecs);
+ return default_delay(usecs);
}
if (flash->mst->buses_supported & BUS_SPI) {
@@ -282,7 +282,7 @@ void programmer_delay(const struct flashctx *flash, unsigned int usecs)
return flash->mst->par.delay(flash, usecs);
}
- return internal_delay(usecs);
+ return default_delay(usecs);
}
int read_memmapped(struct flashctx *flash, uint8_t *buf, unsigned int start,
@@ -260,18 +260,18 @@ void programmer_delay(const struct flashctx *flash, unsigned int usecs)
return;
/**
- * Drivers should either use internal_delay() directly or their
+ * Drivers should either use default_delay() directly or their
* own custom delay. Only core flashrom logic calls programmer_delay()
* which should always have a valid flash context. A NULL context
@@ -260,18 +260,18 @@ void programmer_delay(const struct flashctx *flash, unsigned int usecs)
* which should always have a valid flash context. A NULL context
* more than likely indicates a layering violation or BUG however
- * for now dispatch a internal_delay() as a safe default for the NULL
+ * for now dispatch a default_delay() as a safe default for the NULL
* base case.
*/